.large_image_thumbnail
  position relative

.large_image_annotation_badge
  position absolute
  top 0
  right 0
  transform scale(1) translate(50%, -50%)
  transform-origin 100% 0
  height 20px
  padding 0 6px
  z-index 10
  min-width 20px
  display flex
  align-items center
  justify-content center
  font-size 80%
  line-height 1
  background-color lightgrey
  color black
  border-radius 10px

  &.hidden
    display none
